@@ -186,6 +186,19 @@ my_grab_button (Display * dpy, unsigned int button, unsigned int modifier,
 
 
 
+void
+ungrab_all_keys (Display * dpy)
+{
+  int screen;
+  
+  for (screen = 0; screen < ScreenCount (dpy); screen++)
+    {
+      XUngrabKey (dpy, AnyKey, AnyModifier, RootWindow (dpy, screen));
+      XUngrabButton (dpy, AnyButton, AnyModifier, RootWindow (dpy, screen));
+    }
+}
+
+
 void
 grab_keys (Display * dpy)
 {
@@ -202,6 +215,8 @@ grab_keys (Display * dpy)
 	      max);
     }
 
+  ungrab_all_keys (dpy);
+ 
 
   for (i = 0; i < nb_keys; i++)
     {
