@@ -323,10 +323,11 @@ show_defaults_rc (void)
 static void
 show_defaults_guile_rc (void)
 {
-  printf (";;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;\n");
-  printf (";; Start of xbindkeys configuration ;\n");
-  printf (";;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;\n");
+  printf (";;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;\n");
+  printf (";; Start of xbindkeys guile configuration ;;\n");
+  printf (";;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;\n");
   printf (";; This configuration is guile based.\n");
+  printf (";;   http://www.gnu.org/software/guile/guile.html\n");
   printf (";; any functions that work in guile will work here.\n");
   printf (";; see EXTRA FUNCTIONS:\n");
   printf ("\n");
@@ -357,12 +358,10 @@ show_defaults_guile_rc (void)
   printf (";; To dissable them, call the functions with #f\n");
   printf ("\n");
   printf ("\n");
-  printf (";;EXTRA FUNCTIONS:\n");
+  printf (";;;;EXTRA FUNCTIONS: Enable numlock, scrolllock or capslock usage\n");
   printf (";;(set-numlock! #t)\n");
   printf (";;(set-scrolllock! #t)\n");
   printf (";;(set-capslock! #t)\n");
-  printf (";;that is, xbindkey can take a list of modifiers ended by a key\n");
-  printf (";;                  or it can just take a plain key.\n");
   printf ("\n");
   printf (";;;;; Scheme API reference\n");
   printf (";;;;\n");
@@ -448,9 +447,49 @@ show_defaults_guile_rc (void)
   printf ("		       (set! time (current-time)))))\n");
   printf ("\n");
   printf ("\n");
-  printf (";;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;\n");
-  printf (";; End of xbindkeys configuration ;;\n");
-  printf (";;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;\n");
+  printf (";; Chording keys test: Start differents program if only one key is\n");
+  printf (";; pressed or another if two keys are pressed.\n");
+  printf (";; If key1 is pressed start cmd-k1\n");
+  printf (";; If key2 is pressed start cmd-k2\n");
+  printf (";; If both are pressed start cmd-k1-k2 or cmd-k2-k1 following the\n");
+  printf (";;   release order\n");
+  printf ("(define (define-chord-keys key1 key2 cmd-k1 cmd-k2 cmd-k1-k2 cmd-k2-k1)\n");
+  printf ("    \"Define chording keys\"\n");
+  printf ("  (let ((k1 #f) (k2 #f))\n");
+  printf ("    (xbindkey-function key1 (lambda () (set! k1 #t)))\n");
+  printf ("    (xbindkey-function key2 (lambda () (set! k2 #t)))\n");
+  printf ("    (xbindkey-function (cons 'release key1)\n");
+  printf ("		       (lambda ()\n");
+  printf ("			 (if (and k1 k2)\n");
+  printf ("			     (run-command cmd-k1-k2)\n");
+  printf ("			     (if k1 (run-command cmd-k1)))\n");
+  printf ("			 (set! k1 #f) (set! k2 #f)))\n");
+  printf ("    (xbindkey-function (cons 'release key2)\n");
+  printf ("		       (lambda ()\n");
+  printf ("			 (if (and k1 k2)\n");
+  printf ("			     (run-command cmd-k2-k1)\n");
+  printf ("			     (if k2 (run-command cmd-k2)))\n");
+  printf ("			 (set! k1 #f) (set! k2 #f)))))\n");
+  printf ("\n");
+  printf ("\n");
+  printf (";; Example:\n");
+  printf (";;   Shift + b:1                   start an xterm\n");
+  printf (";;   Shift + b:3                   start an rxvt\n");
+  printf (";;   Shift + b:1 then Shift + b:3  start gv\n");
+  printf (";;   Shift + b:3 then Shift + b:1  start xpdf\n");
+  printf ("\n");
+  printf ("(define-chord-keys '(shift \"b:1\") '(shift \"b:3\")\n");
+  printf ("  \"xterm\" \"rxvt\" \"gv\" \"xpdf\")\n");
+  printf ("\n");
+  printf (";; Here the release order have no importance\n");
+  printf (";; (the same program is started in both case)\n");
+  printf ("(define-chord-keys '(alt \"b:1\") '(alt \"b:3\")\n");
+  printf ("  \"gv\" \"xpdf\" \"xterm\" \"xterm\")\n");
+  printf ("\n");
+  printf ("\n");  
+  printf (";;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;\n");
+  printf (";; End of xbindkeys guile configuration ;;\n");
+  printf (";;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;\n");
 
   exit (1);
 }
